example.add_numbers

example.add_numbers(a, b)

Add two numbers together and return the result.

This is an example function with a numpy style docstring. We recommend using this style for consistency and readability.

Parameters

Name Type Description Default
a float The first number to add. required
b float The second number to add. required

Returns

Name Type Description
float The sum of the two numbers.

Examples

>>> add_numbers(3, 5)
8
>>> add_numbers(-2, 7)
5